@@ -1,15 +1,10 @@
 import logging
 import os
-import string
-
-import plumbum
 
 from devassistant import assistant_base
 from devassistant import exceptions
-from devassistant import settings
 from devassistant.assistants.command_formatter import CommandFormatter
 from devassistant.assistants.commands import run_command
-from devassistant.command_helpers import ClHelper, RPMHelper, YUMHelper, PathHelper
 from devassistant.logger import logger
 from devassistant import yaml_snippet_loader
 
@@ -38,10 +33,13 @@ class YamlAssistant(assistant_base.AssistantBase):
                 logger.warning('Unknown logger type {0}, ignoring.'.format(handler_type))
 
     def dependencies(self, **kwargs):
-        for sect in self._dependencies:
-            condition, section = sect.popitem()
-            if condition == 'default' or kwargs.get(condition[1:], False):
-                self._dependencies_section(section)
+        sections = [getattr(self, '_dependencies', [])]
+        for arg in kwargs:
+            if '_dependencies_{0}'.format(arg) in dir(self):
+                sections.append(getattr(self, '_dependencies_{0}'.format(arg)))
+
+        for sect in sections:
+            self._dependencies_section(sect)
 
     def _dependencies_section(self, section, **kwargs):
         for dep in section:
@@ -78,12 +76,12 @@ class YamlAssistant(assistant_base.AssistantBase):
                         self._run_one_section(comm, **kwargs)
                     elif len(section) > i + 1:
                         next_section_dict = section[i + 1]
-                        next_section_comm_type, next_section_comm = next_section_dict.items()[0]
+                        next_section_comm_type, next_section_comm = list(next_section_dict.items())[0]
                         if next_section_comm_type == 'else':
                             execute_else = True
                 elif comm_type == 'else':
                     # else on its own means error, otherwise execute it
-                    if not section[i - 1].items()[0][0].startswith('if'):
+                    if not list(section[i - 1].items())[0][0].startswith('if'):
                         logger.warning('Yaml error: encountered "else" with no associated "if", skipping.')
                     elif execute_else:
                         execute_else = False
